translate.convert.po2web2py

Package translate :: Package convert :: Module po2web2py |
[hide private]
[frames] | no frames]

# Module po2web2py

source code

convert GNU/gettext PO files to web2py translation dictionaries (.py)

Classes | [hide private]
| po2pydict

Functions | [hide private]
convertpy(inputfile, outputfile, templatefile=None, includefuzzy=False) | source code
main(argv=None) | source code

Variables | [hide private]
| __package__ = ``'``translate.convert``'``

Imports: factory